
/*
 * Copyright (C) 2008 - INRIA
 * Copyright (C) 2011 - DIGITEO - Michael Baudin
 *
 * This file must be used under the terms of the CeCILL.
 * This source file is licensed as described in the file COPYING, which
 * you should have received as part of this distribution.  The terms
 * are also available at
 * http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
 *
 */
 
#ifndef _DISTFUN_C_H_
#define _DISTFUN_C_H_

#ifdef _MSC_VER
	#if LIBDISTFUN_C_EXPORTS 
		#define DISTFUN_C_IMPORTEXPORT __declspec (dllexport)
	#else
		#define DISTFUN_C_IMPORTEXPORT __declspec (dllimport)
	#endif
#else
	#define DISTFUN_C_IMPORTEXPORT
#endif

#undef __BEGIN_DECLS
#undef __END_DECLS
#ifdef __cplusplus
# define __BEGIN_DECLS extern "C" {
# define __END_DECLS }
#else
# define __BEGIN_DECLS /* empty */
# define __END_DECLS /* empty */
#endif

__BEGIN_DECLS

#include "machine.h"

#define min(a,b) ((a) <= (b) ? (a) : (b))
#define max(a,b) ((a) >= (b) ? (a) : (b))
#define TRUE_ (1)
#define FALSE_ (0)

extern /* Subroutine */ int basout_(int *, float *, char *, long int);
extern double dlamch_(char *, long int);

/* the available generators : */
enum {MT, KISS, CLCG4, CLCG2, URAND, FSULTRA};
/* the current generator : */
static int current_gen = MT;
/* for clcg4 : the current virtual gen (current_clcg4 in [0, Maxgen]) */
static int current_clcg4 = 0;
/* Number of Generators in Scilab */
#define NbGenInScilab 6
/*  names at the scilab level */
static char *names_gen[NbGenInScilab] = { "mt",  "kiss","clcg4", "clcg2", "urand", "fsultra" };


/* header for the Mersenne Twister */
DISTFUN_C_IMPORTEXPORT unsigned int randmt(void);
DISTFUN_C_IMPORTEXPORT int set_state_mt_simple(double s);
DISTFUN_C_IMPORTEXPORT int set_state_mt(double seed_array[]);
DISTFUN_C_IMPORTEXPORT void get_state_mt(double state[]);

/* header for kiss */
DISTFUN_C_IMPORTEXPORT unsigned int kiss(void);
DISTFUN_C_IMPORTEXPORT int set_state_kiss(double g1, double g2, double g3, double g4);
DISTFUN_C_IMPORTEXPORT void get_state_kiss(double g[]);

/* header for clcg2 */
DISTFUN_C_IMPORTEXPORT unsigned int clcg2(void);
DISTFUN_C_IMPORTEXPORT int set_state_clcg2(double g1, double g2);
DISTFUN_C_IMPORTEXPORT void get_state_clcg2(double g[]);

/* header for scilab urand */
DISTFUN_C_IMPORTEXPORT unsigned int urandc(void);
DISTFUN_C_IMPORTEXPORT int set_state_urand(double g);
DISTFUN_C_IMPORTEXPORT void get_state_urand(double g[]);

/* header for scilab fsultra */
DISTFUN_C_IMPORTEXPORT unsigned int fsultra(void);
DISTFUN_C_IMPORTEXPORT int set_state_fsultra(double g[]);
DISTFUN_C_IMPORTEXPORT int set_state_fsultra_simple(double g1,double g2);
DISTFUN_C_IMPORTEXPORT void get_state_fsultra(double g[]);

/* header for scilab clcg4 */
#define Maxgen_clcg4  100
DISTFUN_C_IMPORTEXPORT int set_seed_clcg4(int g, double s0, double s1, double s2, double s3);
DISTFUN_C_IMPORTEXPORT void get_state_clcg4(int g, double s[4]);
typedef  enum {InitialSeed, LastSeed, NewSeed}  SeedType;
DISTFUN_C_IMPORTEXPORT void init_generator_clcg4(int g, SeedType Where);
DISTFUN_C_IMPORTEXPORT void advance_state_clcg4(int g, int k);
DISTFUN_C_IMPORTEXPORT int set_initial_seed_clcg4(double s0, double s1, double s2, double s3);
DISTFUN_C_IMPORTEXPORT unsigned int clcg4(int g);



DISTFUN_C_IMPORTEXPORT int C2F(setgmn) (double *meanv, double *covm, int *ldcovm, int *p, double *parm, int *ierr);
DISTFUN_C_IMPORTEXPORT double C2F(genbet) (double *aa, double *bb);
DISTFUN_C_IMPORTEXPORT double C2F(genchi) (double *df);
DISTFUN_C_IMPORTEXPORT double C2F(genexp) (double *av);
DISTFUN_C_IMPORTEXPORT double C2F(genf) (double *dfn, double *dfd);
DISTFUN_C_IMPORTEXPORT double C2F(gengam) (double *a, double *r__);
DISTFUN_C_IMPORTEXPORT double C2F(gennch) (double *df, double *xnonc);
DISTFUN_C_IMPORTEXPORT double C2F(gennf) (double *dfn, double *dfd, double *xnonc);
DISTFUN_C_IMPORTEXPORT double C2F(gennor) (double *av, double *sd);
DISTFUN_C_IMPORTEXPORT double C2F(sdot) (int *n, double *sx, int *incx, double *sy, int *incy);
DISTFUN_C_IMPORTEXPORT double C2F(sexpo) (void);
DISTFUN_C_IMPORTEXPORT double C2F(sgamma) (double *a);
DISTFUN_C_IMPORTEXPORT double igngeom(double p);
DISTFUN_C_IMPORTEXPORT int C2F(genmn) (double *parm, double *x, double *work);
DISTFUN_C_IMPORTEXPORT int C2F(genmul) (int *n, double *p, int *ncat, int *ix);
DISTFUN_C_IMPORTEXPORT int C2F(genprm) (double *array, int *larray);
DISTFUN_C_IMPORTEXPORT int C2F(ignbin) (int *n, double *pp);
DISTFUN_C_IMPORTEXPORT int C2F(ignnbn) (int *n, double *p);
DISTFUN_C_IMPORTEXPORT int C2F(ignpoi) (double *mu);
DISTFUN_C_IMPORTEXPORT int C2F(spofa) (double *a, int *lda, int *n, int *info);
DISTFUN_C_IMPORTEXPORT double C2F(ranf)(void);
DISTFUN_C_IMPORTEXPORT double ignlgi(void);
DISTFUN_C_IMPORTEXPORT double C2F(ignuin)(double *a, double *b);


DISTFUN_C_IMPORTEXPORT double algdiv_(double *a, double *b);
DISTFUN_C_IMPORTEXPORT double alnrel_(double *a);
DISTFUN_C_IMPORTEXPORT double spmpar_(int *i__);
DISTFUN_C_IMPORTEXPORT double snorm_(void);
DISTFUN_C_IMPORTEXPORT int setgmn_(double *meanv, double *covm, int *
	ldcovm, int *p, double *parm, int *ierr);
DISTFUN_C_IMPORTEXPORT int ipmpar_(int *i__);
DISTFUN_C_IMPORTEXPORT double gennf_(double *dfn, double *dfd, double *xnonc);
DISTFUN_C_IMPORTEXPORT double genf_(double *dfn, double *dfd);
DISTFUN_C_IMPORTEXPORT int dinvr_0_(int n__, int *status, double *x, 
	double *fx, long int *qleft, long int *qhi, double *zsmall, 
	double *zbig, double *zabsst, double *zrelst, double *
	zstpmu, double *zabsto, double *zrelto);
DISTFUN_C_IMPORTEXPORT double rlog_(double *x);
DISTFUN_C_IMPORTEXPORT double rlog1_(double *x);
DISTFUN_C_IMPORTEXPORT double rexp_(double *x);
DISTFUN_C_IMPORTEXPORT double rcomp_(double *a, double *x);
DISTFUN_C_IMPORTEXPORT double psi1_(double *xx);
DISTFUN_C_IMPORTEXPORT int phrtsd_(char *phrase, int *phrasel, int *seed1, 
	int *seed2, long int phrase_len);
DISTFUN_C_IMPORTEXPORT double logp1_(double *x);
DISTFUN_C_IMPORTEXPORT int ignnbn_(int *n, double *p);
DISTFUN_C_IMPORTEXPORT double gsumln_(double *a, double *b);
DISTFUN_C_IMPORTEXPORT int gratio_(double *a, double *x, double *ans, 
	double *qans, int *ind);
DISTFUN_C_IMPORTEXPORT int grat1_(double *a, double *x, double *r__, 
	double *p, double *q, double *eps);
DISTFUN_C_IMPORTEXPORT double genunf_(double *low, double *high);
DISTFUN_C_IMPORTEXPORT int genprm_(double *array, int *larray);
DISTFUN_C_IMPORTEXPORT double gennor_(double *av, double *sd);
DISTFUN_C_IMPORTEXPORT double gennch_(double *df, double *xnonc);
DISTFUN_C_IMPORTEXPORT int genmul_(int *n, double *p, int *ncat, 
	int *ix);
DISTFUN_C_IMPORTEXPORT int genmn_(double *parm, double *x, double *work);
DISTFUN_C_IMPORTEXPORT double gengam_(double *a, double *r__);
DISTFUN_C_IMPORTEXPORT double genexp_(double *av);
DISTFUN_C_IMPORTEXPORT double genchi_(double *df);
DISTFUN_C_IMPORTEXPORT double gamma_(double *a);
DISTFUN_C_IMPORTEXPORT double gamln_(double *a);
DISTFUN_C_IMPORTEXPORT double gamln1_(double *a);
DISTFUN_C_IMPORTEXPORT int gaminv_(double *a, double *x, double *x0, 
	double *p, double *q, int *ierr);
DISTFUN_C_IMPORTEXPORT double gam1_(double *a);
DISTFUN_C_IMPORTEXPORT double fpser_(double *a, double *b, double *x, double *
	eps);
DISTFUN_C_IMPORTEXPORT double exparg_(int *l);
DISTFUN_C_IMPORTEXPORT double esum_(int *mu, double *x);
DISTFUN_C_IMPORTEXPORT double erfc1_(int *ind, double *x);
DISTFUN_C_IMPORTEXPORT double erf_(double *x);
DISTFUN_C_IMPORTEXPORT int dzror_0_(int n__, int *status, double *x, 
	double *fx, double *xlo, double *xhi, long int *qleft, 
	long int *qhi, double *zxlo, double *zxhi, double *zabstl, 
	double *zreltl);
DISTFUN_C_IMPORTEXPORT double dt1_(double *p, double *q, double *df);
DISTFUN_C_IMPORTEXPORT double dinvnr_(double *p, double *q);
DISTFUN_C_IMPORTEXPORT double dcddexpm1_(double *x);
DISTFUN_C_IMPORTEXPORT double devlpl_(double *a, int *n, double *x);
DISTFUN_C_IMPORTEXPORT int cumt_(double *t, double *df, double *cum, 
	double *ccum);
DISTFUN_C_IMPORTEXPORT int cumpoi_(double *s, double *xlam, double *cum,
	 double *ccum);
DISTFUN_C_IMPORTEXPORT int cumnor_(double *arg, double *result, double *
	ccum);
DISTFUN_C_IMPORTEXPORT int cumnbn_(double *s, double *xn, double *pr, 
	double *ompr, double *cum, double *ccum);
DISTFUN_C_IMPORTEXPORT int cumgam_(double *x, double *a, double *cum, 
	double *ccum);
DISTFUN_C_IMPORTEXPORT int cumfnc_(double *f, double *dfn, double *dfd, 
	double *pnonc, double *cum, double *ccum);
DISTFUN_C_IMPORTEXPORT int cumf_(double *f, double *dfn, double *dfd, 
	double *cum, double *ccum);
DISTFUN_C_IMPORTEXPORT int cumchn_(double *x, double *df, double *pnonc,
	 double *cum, double *ccum);
DISTFUN_C_IMPORTEXPORT int cumchi_(double *x, double *df, double *cum, 
	double *ccum);
DISTFUN_C_IMPORTEXPORT int cumbin_(double *s, double *xn, double *pr, 
	double *ompr, double *cum, double *ccum);
DISTFUN_C_IMPORTEXPORT int cumbet_(double *x, double *y, double *a, 
	double *b, double *cum, double *ccum);
DISTFUN_C_IMPORTEXPORT int cdft_(int *which, double *p, double *q, 
	double *t, double *df, int *status, double *bound);
DISTFUN_C_IMPORTEXPORT int cdfpoi_(int *which, double *p, double *q, 
	double *s, double *xlam, int *status, double *bound);
DISTFUN_C_IMPORTEXPORT int cdfnor_(int *which, double *p, double *q, 
	double *x, double *mean, double *sd, int *status, 
	double *bound);
DISTFUN_C_IMPORTEXPORT int cdfnbn_(int *which, double *p, double *q, 
	double *s, double *xn, double *pr, double *ompr, 
	int *status, double *bound);
DISTFUN_C_IMPORTEXPORT int cdfgam_(int *which, double *p, double *q, 
	double *x, double *shape, double *scale, int *status, 
	double *bound);
DISTFUN_C_IMPORTEXPORT int cdffnc_(int *which, double *p, double *q, 
	double *f, double *dfn, double *dfd, double *phonc, 
	int *status, double *bound);
DISTFUN_C_IMPORTEXPORT int cdff_(int *which, double *p, double *q, 
	double *f, double *dfn, double *dfd, int *status, 
	double *bound);
DISTFUN_C_IMPORTEXPORT int cdfchn_(int *which, double *p, double *q, 
	double *x, double *df, double *pnonc, int *status, 
	double *bound);
DISTFUN_C_IMPORTEXPORT int cdfchi_(int *which, double *p, double *q, 
	double *x, double *df, int *status, double *bound);
DISTFUN_C_IMPORTEXPORT int cdfbin_(int *which, double *p, double *q, 
	double *s, double *xn, double *pr, double *ompr, 
	int *status, double *bound);
DISTFUN_C_IMPORTEXPORT int cdfbet_(int *which, double *p, double *q, 
	double *x, double *y, double *a, double *b, int *
	status, double *bound);
DISTFUN_C_IMPORTEXPORT double bup_(double *a, double *b, double *x, double *y, 
	int *n, double *eps);
DISTFUN_C_IMPORTEXPORT double brcomp_(double *a, double *b, double *x, double *y);
DISTFUN_C_IMPORTEXPORT double brcmp1_(int *mu, double *a, double *b, double *x, 
	double *y);
DISTFUN_C_IMPORTEXPORT int bratio_(double *a, double *b, double *x, 
	double *y, double *w, double *w1, int *ierr);
DISTFUN_C_IMPORTEXPORT double bpser_(double *a, double *b, double *x, double *
	eps);
DISTFUN_C_IMPORTEXPORT int bgrat_(double *a, double *b, double *x, 
	double *y, double *w, double *eps, int *ierr);
DISTFUN_C_IMPORTEXPORT double bfrac_(double *a, double *b, double *x, double *y, 
	double *lambda, double *eps);
DISTFUN_C_IMPORTEXPORT double betaln_(double *a0, double *b0);
DISTFUN_C_IMPORTEXPORT double bcorr_(double *a0, double *b0);
DISTFUN_C_IMPORTEXPORT double apser_(double *a, double *b, double *x, double *
	eps);
DISTFUN_C_IMPORTEXPORT double alnrel_(double *a);
DISTFUN_C_IMPORTEXPORT double alngam_(double *x);
DISTFUN_C_IMPORTEXPORT double algdiv_(double *a, double *b);
DISTFUN_C_IMPORTEXPORT double stvaln_(double *p);
DISTFUN_C_IMPORTEXPORT double basym_(double *a, double *b, double *lambda, 
	double *eps);
DISTFUN_C_IMPORTEXPORT double lnp1m1_(double *s);
DISTFUN_C_IMPORTEXPORT int C2F(largestint)(void);

__END_DECLS

#endif /** _DISTFUN_C_H_   **/




