// Copyright (C) 2009 - 2011 - DIGITEO - Michael Baudin
//
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt

// <-- JVM NOT MANDATORY -->
// <-- ENGLISH IMPOSED -->


// Check expansion of a and b
p = [0.01 0.5 0.99];
x = distfun_betainv(p,10,5);
expected = [0.372565305114573   0.674248844713787   0.898071404278149];
assert_checkalmostequal ( x , expected , 1.e-8 );
//
// Check with expanded a and b
p = [0.01 0.5 0.99];
x = distfun_betainv(p,[8 9 10],[5 6 7]);
expected = [0.302404222173137   0.604556744392119   0.833540311685497];
assert_checkalmostequal ( x , expected , 1.e-8 );
/////////////////////////////////////////////////////////////////////
//
// Test accuracy of distfun_betainv
//

// http://bugzilla.scilab.org/show_bug.cgi?id=9976
// The inverse cdfbet function is sometimes wrong.
// This makes a bug for p=0, and this is why we comment it.

// Values computed from Mathematica
table = [
  0.5     , 1.0 , 2.0 , 0.2928932188134524    , 1000*%eps
  //0.0     , 1.0 , 2.0 , 0.0                   , 10 * %eps
  1.0     , 1.0 , 2.0 , 1.0                   , 10 * %eps
  0.6     , 1.0 , 2.0 , 0.367544467966324     , 1.e-8
  0.8     , 1.0 , 2.0 , 0.552786404500042     , 1.e-8
  0.9     , 1.0 , 2.0 , 0.683772233983162     , 1.e-8
  0.2     , 1.0 , 2.0 , 0.1055728090000841    , 1.e-8
  0.1     , 1.0 , 2.0 , 0.0513167019494862    , 1.e-8
  1.e-2   , 1.0 , 2.0 , 0.005012562893380045  , 1.e-8
  1.e-5   , 1.0 , 2.0 , 5.0000125000625e-06   , 1.e-8
  1.e-10  , 1.0 , 2.0 , 5.00000000012501e-11  , 1.e-8
  1.e-20  , 1.0 , 2.0 , 4.999999999999987e-21 , 1.e-8
  1.e-50  , 1.0 , 2.0 , 5e-51                 , 10 * %eps
  1.e-100 , 1.0 , 2.0 , 5.00000000000001e-101 , 1.e50
];
nt = size(table,"r");
for k = 1 : nt
  p = table(k,1);
  a = table(k,2);
  b = table(k,3);
  expected = table(k,4);
  precision = table(k,5);
  computed = distfun_betainv ( p , a , b );
  assert_checkalmostequal ( computed , expected , precision );
end

//
// Check vectorization
a = 1;
b = 3;
p = linspace(0.1,0.9,10);
x = distfun_betainv ( p , a , b );
x2 = [];
for i = 1 : 10
    x2(1,i) = distfun_betainv ( p(i) , a , b );
end
assert_checkequal(x,x2);
//
// Check upper tail
p = [0.01 0.5 0.99];
x = distfun_betainv(p,10,5,%f);
expected = [0.8980714    0.6742488    0.3725653];
assert_checkalmostequal ( x , expected , 1.e-6 );
//
// Check upper tail with R
x = distfun_betainv(0.99,10,5);
assert_checkalmostequal ( x , 0.8980714 , 1.e-6 );
x = distfun_betainv(0.99,10,5,%f);
assert_checkalmostequal ( x , 0.3725653 , 1.e-6 );
x = distfun_betainv(1.e-20,10,5,%f);
assert_checkalmostequal ( x , 0.9999781 , 1.e-6 );
