// Copyright (C) 2009 - 2011 - DIGITEO - Michael Baudin
//
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt

// <-- JVM NOT MANDATORY -->
// <-- ENGLISH IMPOSED -->


//
// Check expansion of a and expansion of b
computed = distfun_betapdf ( 0.1:0.2:0.9 , 2 , 3 );
expected = [0.9720    1.7640    1.5000    0.7560    0.1080];
assert_checkalmostequal ( computed , expected , 10 * %eps );
//
// Check with expanded arguments
computed = distfun_betapdf ( 0.1:0.2:0.9 , [2 3 4 5 6], [5 4 3 2 1] );
expected = [1.9683    1.8522    1.8750    2.1609    3.54294];
assert_checkalmostequal ( computed , expected , 10 * %eps );
//
// Check at the bounds
computed = distfun_betapdf ( [-1 0 1 2] , 1 , 2 );
assert_checkequal ( computed , [0 2 0 0] );
//
computed = distfun_betapdf([-1 0 1 2],1,3);
assert_checkequal ( computed , [0 3 0 0] );
/////////////////////////////////////////////////////////////////////
//
// Test the accuracy of distfun_betapdf
//

// Table of inputs
// [x shape scale P precision]
precision = 10*%eps;
table = [
   -1  , 1 , 2 , 0   , 10 * %eps 
   0   , 1 , 2 , 2   , 10 * %eps
   0.1 , 1 , 2 , 1.8 , 10 * %eps
   0.2 , 1 , 2 , 1.6 , 10 * %eps
   0.4 , 1 , 2 , 1.2 , 10 * %eps
   0.6 , 1 , 2 , 0.8 , 10 * %eps
   0.8 , 1 , 2 , 0.4 , 10 * %eps
   0.9 , 1 , 2 , 0.2 , 10 * %eps
   1   , 1 , 2 , 0   , 10 * %eps
   2   , 1 , 2 , 0   , 10 * %eps
];

ntests = size(table,"r");
for i = 1 : ntests
  x = table(i,1);
  a = table(i,2);
  b = table(i,3);
  expected = table(i,4);
  precision = table(i,5);
  computed = distfun_betapdf ( x , a , b );
  assert_checkalmostequal ( computed , expected , precision );
end

//
// Check vectorization
a = 1;
b = 3;
x = linspace(0.1,0.9,10);
p = distfun_betapdf ( x , a , b );
p2 = [];
for i = 1 : 10
    p2(1,i) = distfun_betapdf ( x(i) , a , b );
end
assert_checkequal(p,p2);
//
// Check consistency CDF/PDF
n = 10;
a = 3;
b = 5;
p = linspace(0.01,0.99,n)';
x = distfun_betainv(p,a,b);
p1 = distfun_betapdf ( x , a , b );
p2 = [];
for i = 1 : n
    p2(i) = derivative(list(distfun_betacdf,a,b),x(i));
end
assert_checkalmostequal ( p1 , p2 , 1.e-7 , [] , "element");
