// Copyright (C) 2009-2011 - DIGITEO - Michael Baudin
//
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt

// <-- JVM NOT MANDATORY -->
// <-- ENGLISH IMPOSED -->


//
// Assessing the quality of the Normal distribution function
// References
//   Yalta, A. T. 2008. The accuracy of statistical distributions in Microsoft®Excel 2007. Comput. Stat. Data Anal. 52, 10 (Jun. 2008), 4579-4586. DOI= http://dx.doi.org/10.1016/j.csda.2008.03.005 
//   Computation of Statistical Distributions (ELV), Leo Knüsel 
// Table 5
// Check Gamma distribution with parameters (x, alpha, beta = 1, Sigma = 1)
//


// Table of inputs from Yalta, 2008
// [x shape scale P ]
path=distfun_getpath();
dataset = fullfile(path,"tests","unit_tests","gamma","gammacdf.yalta.dataset.csv");
table = assert_csvread ( dataset , "," , [] , "/#(.*)/" );
x = evstr(table(:,1));
shape = evstr(table(:,2));
scale = evstr(table(:,3));
expected = evstr(table(:,4));
// Caution: this is the rate !
rate = 1 ./ scale;

precision = 1.e-5;
ntests = size(table,"r");
for i = 1 : ntests
  [computed,Q]=cdfgam("PQ",x(i),shape(i),rate(i));
  assert_checkalmostequal ( computed , expected(i) , precision );
  assert_checkalmostequal ( Q , 1 - expected(i) , precision );
end

// Table of inputs computed from R-2.8.1
// [x shape scale PDF-P CDF-P CDF-Q]

// For the inversion of Shape, require only 8 digits, as 
// a consequence of bug #7569: http://bugzilla.scilab.org/show_bug.cgi?id=7569
//
// Some tests do not pass:
// http://bugzilla.scilab.org/show_bug.cgi?id=8031
// http://bugzilla.scilab.org/show_bug.cgi?id=8030
//
// Prints the number of accurate digits.

path=distfun_getpath();
dataset = fullfile(path,"tests","unit_tests","gamma","gammacdf.dataset.csv");
table = assert_csvread ( dataset , "," , [] , "/#(.*)/" );
table = evstr(table);

precision = 1.e-12;
precinverse = 1.e-8;

ntests = size(table,"r");
for i = 1 : ntests
  x = table(i,1);
  shape = table(i,2);
  scale = table(i,3);
  p = table(i,5);
  q = table(i,6);
  // Caution: this is the rate !
  rate = 1/scale;
  [p1,q1]=cdfgam("PQ",x,shape,rate);
  x1     = cdfgam("X",shape,rate,p,q);
  shape1 = cdfgam("Shape",rate,p,q,x);
  rate1 = cdfgam("Rate",p,q,x,shape);
  if ( %t ) then
    assert_checkalmostequal ( p1 , p , precision );
    assert_checkalmostequal ( q1 , q , precision );
    assert_checkalmostequal ( x1 , x , precision );
    assert_checkalmostequal ( shape1 , shape , precinverse );
    assert_checkalmostequal ( rate1 , rate , precinverse );
  end
  if ( %f ) then
    dp = assert_computedigits ( p1 , p );
    dq = assert_computedigits ( q1 , q );
    dx = assert_computedigits ( x1 , x );
    ds = assert_computedigits ( shape1 , shape );
    dr = assert_computedigits ( rate1 , rate );
    mprintf("Test #%3d/%3d: Digits p1= %.1f, q1=%.1f, X= %.1f, S= %.1f, R= %.1f\n",i,ntests,dp,dq,dx,ds,dr);
  end
end

