// Copyright (C) 2011 - INRIA - Michael Baudin
// Copyright (C) 2011 - DIGITEO - Michael Baudin
//
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt


//
// <-- JVM NOT MANDATORY -->
// <-- ENGLISH IMPOSED -->

x = 2;
mu = 1/3;
computed = distfun_exppdf ( x , mu );
expected = 7.436256529999075e-3;
assert_checkalmostequal ( computed , expected , 10*%eps );
//
// Check matrix arguments
x = [2 2 2];
mu = 1 ./ [3 3 3];
computed = distfun_exppdf ( x , mu );
expected = 7.436256529999075e-3*ones(1,3); // From Scilab itself
assert_checkalmostequal ( computed , expected , 10*%eps );
//
// Check argument expansion
x = [2 2 2];
mu = 1/3;
computed = distfun_exppdf ( x , mu );
expected = 7.436256529999075e-3*ones(1,3); // From Scilab itself
assert_checkalmostequal ( computed , expected , 10*%eps );

//
// Check vectorization
mu = 3;
x = linspace(0.1,0.9,10);
p = distfun_exppdf ( x , mu );
p2 = [];
for i = 1 : 10
    p2(1,i) = distfun_exppdf ( x(i) , mu );
end
assert_checkequal(p,p2);
//
// Check consistency CDF/PDF
n = 10;
mu = 3;
p = linspace(0.01,0.99,n)';
x = distfun_expinv(p,mu);
p1 = distfun_exppdf ( x , mu );
p2 = [];
for i = 1 : n
    p2(i) = derivative(list(distfun_expcdf,mu),x(i));
end
assert_checkalmostequal ( p1 , p2 , 1.e-7 , [] , "element");
