// Copyright (C) 2011 - DIGITEO - Michael Baudin
//
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt

// <-- JVM NOT MANDATORY -->

// Test x scalar, a scalar, b expanded
b = 1:5;
p = distfun_gamcdf(1,1,b);
e = [  ..
6.321205588285576660D-01  ..
3.934693402873664647D-01  ..
2.834686894262107293D-01  ..
2.211992169285951215D-01  ..
1.812692469220181790D-01  ..
];
assert_checkalmostequal(p,e);
//
a = 1:6;
b = 5:10;
p = distfun_gamcdf(a.*b,a,b);
e = [  0.6321  0.5940  0.5768  0.5665  0.5595  0.5543];
assert_checkalmostequal(p,e,1.e-3);
// Plot the function
if (%f) then
    shape = [1 2 3 5 9];
    scale = [2 2 2 1 0.5];
    cols = [1 2 3 4 5];
    nf = size(cols,"*");
    lgd = [];
    for k = 1 : nf
        x = linspace(0,20,1000);
        y = distfun_gamcdf ( x , shape(k) , scale(k) );
        plot(x,y)
        str = msprintf("shape=%s, scale=%s",..
          string(shape(k)),string(scale(k)));
        lgd($+1) = str;
    end
    h = gcf();
    for k = 1 : nf
        h.children.children.children(nf - k + 1).foreground = cols(k);
    end
    xtitle("Gamma CDF","x","f")
    legend(lgd);
end

///////////////////////////////////////////////////////////////
// Accuracy test
// Numerical values computed from Yalta

precision = 1.e-5;
path=distfun_getpath();
dataset = fullfile(path,"tests","unit_tests","gamma","gammacdf.yalta.dataset.csv");
table = assert_csvread ( dataset , "," , [] , "/#(.*)/" );
table = evstr(table);

ntests = size(table,"r");
for i = 1 : ntests
  x = table(i,1);
  shape = table(i,2);
  scale = table(i,3);
  expected = table(i,4);
  computed = distfun_gamcdf(x,shape,scale);
  // Compute number of significant digits
  d = assert_computedigits ( computed , expected );
  //mprintf("Test #%d/%d: Digits = %.1f\n",i,ntests,d);
  assert_checkalmostequal ( computed , expected , precision );
end

///////////////////////////////////////////////////////////////
// Accuracy test
// Numerical values computed from R

precision = 10*%eps;
path=distfun_getpath();
dataset = fullfile(path,"tests","unit_tests","gamma","gammacdf.dataset.csv");
table = assert_csvread ( dataset , "," , [] , "/#(.*)/" );
table = evstr(table);

ntests = size(table,"r");
for i = 1 : ntests
  x = table(i,1);
  shape = table(i,2);
  scale = table(i,3);
  expected = table(i,5);
  computed = distfun_gamcdf(x,shape,scale);
  d = assert_computedigits ( computed , expected );
  //mprintf("Test #%d/%d: Digits = %.1f\n",i,ntests,d);
  assert_checkalmostequal ( computed , expected , precision );
end

//
// Check vectorization
shape = 3;
scale = 2;
x = linspace(0.1,20,10);
p = distfun_gamcdf ( x , shape, scale );
p2 = [];
for i = 1 : 10
    p2(1,i) = distfun_gamcdf ( x(i) , shape, scale );
end
assert_checkequal(p,p2);
//
// See upper tail, and compare with R
p = distfun_gamcdf(1,3,5);
assert_checkalmostequal(p,0.0011484812448621334151,10*%eps);
p = distfun_gamcdf(1,3,5,%f);
assert_checkalmostequal(p,0.99885151875513777942,10*%eps);
p = distfun_gamcdf(300,3,5,%f);
assert_checkalmostequal(p, 1.6295866529378136268e-23,100*%eps);
