// Copyright (C) 2011 - DIGITEO - Michael Baudin
//
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt

// <-- JVM NOT MANDATORY -->


b = 1:5;
p = [  ..
6.321205588285576660D-01  ..
3.934693402873664647D-01  ..
2.834686894262107293D-01  ..
2.211992169285951215D-01  ..
1.812692469220181790D-01  ..
];
x = distfun_gaminv(p,1,b);
assert_checkalmostequal(x,ones(1,5));
//
a = 1:5;
b = 6:10;
x = distfun_gaminv(distfun_gamcdf(1:5,a,b),a,b);
assert_checkalmostequal(x,1:5);

///////////////////////////////////////////////////////////////
// Accuracy test
// Numerical values computed from R

precision = 1.e-7;
path=distfun_getpath();
dataset = fullfile(path,"tests","unit_tests","gamma","gammacdf.dataset.csv");
table = assert_csvread ( dataset , "," , [] , "/#(.*)/" );
table = evstr(table);

ntests = size(table,"r");
for i = 1 : ntests
  if ( i == 19 | i == 20 ) then
    // "p out of range"
    continue
  end
  expected = table(i,1);
  shape = table(i,2);
  scale = table(i,3);
  p = table(i,5);
  computed = distfun_gaminv(p,shape,scale);
  d = assert_computedigits ( computed , expected );
  mprintf("Test #%d/%d: Digits = %.1f\n",i,ntests,d);
  assert_checkalmostequal ( computed , expected , precision );
end

///////////////////////////////////////////////////////////////
//
// Check vectorization
shape = 3;
scale = 2;
mu = 3;
p = linspace(0.1,0.9,10);
x = distfun_gaminv ( p , shape, scale );
x2 = [];
for i = 1 : 10
    x2(1,i) = distfun_gaminv ( p(i) , shape, scale );
end
assert_checkequal(x,x2);
//
// See upper tail, compare with R
p = distfun_gaminv(1.e-20,3,5,%f);
assert_checkalmostequal(p, 266.7488703551273943,10*%eps);
