// Copyright (C) 2009 - 2011 - DIGITEO - Michael Baudin
//
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt

// <-- JVM NOT MANDATORY -->
// <-- ENGLISH IMPOSED -->

//
// Test distfun_gampdf
//
// Test x scalar, a scalar, b expanded
b = 1:5;
computed = distfun_gampdf(1,1,b);
expected = [3.678794411714423340D-01,3.032653298563167121D-01,2.388437701912631272D-01,1.947001957678512196D-01,1.637461506155963586D-01];
assert_checkalmostequal ( computed, expected, %eps );
//
// Test all expanded
computed = distfun_gampdf([1 1],[2 2],[3 3]);
expected = [7.961459006375437575D-02    7.961459006375437575D-02];
assert_checkalmostequal ( computed, expected, %eps );

///////////////////////////////////////////////////////////////
// Accuracy test
// Numerical values computed from Matlab 7.7.0

precision = 10*%eps;
path=distfun_getpath();
dataset = fullfile(path,"tests","unit_tests","gamma","gammacdf.matlab.dataset.csv");
table = assert_csvread ( dataset , "," , [] , "/#(.*)/" );
table = evstr(table);

ntests = size(table,"r");
for i = 1 : ntests
  x = table(i,1);
  shape = table(i,2);
  scale = table(i,3);
  expected = table(i,4);
  computed = distfun_gampdf(x,shape,scale);
  d = assert_computedigits ( computed , expected );
  //mprintf("Test #%d/%d: Digits = %.1f\n",i,ntests,d);
  assert_checkalmostequal ( computed , expected , precision );
end

///////////////////////////////////////////////////////////////
// Accuracy test
// Numerical values computed from R

precision = 100*%eps;
path=distfun_getpath();
dataset = fullfile(path,"tests","unit_tests","gamma","gammacdf.dataset.csv");
table = assert_csvread ( dataset , "," , [] , "/#(.*)/" );
table = evstr(table);

ntests = size(table,"r");
for i = 1 : ntests
  x = table(i,1);
  shape = table(i,2);
  scale = table(i,3);
  expected = table(i,4);
  computed = distfun_gampdf(x,shape,scale);
  d = assert_computedigits ( computed , expected );
  //mprintf("Test #%d/%d: Digits = %.1f\n",i,ntests,d);
  assert_checkalmostequal ( computed , expected , precision );
end

//
// Check vectorization
shape = 3;
scale = 2;
x = linspace(0.1,20,10);
p = distfun_gampdf ( x , shape, scale );
p2 = [];
for i = 1 : 10
    p2(1,i) = distfun_gampdf ( x(i) , shape, scale );
end
assert_checkequal(p,p2);
//
// Check consistency CDF/PDF
n = 10;
shape = 3;
scale = 2;
p = linspace(0.01,0.99,n)';
x = distfun_gaminv(p,shape, scale);
p1 = distfun_gampdf ( x , shape, scale );
p2 = [];
for i = 1 : n
    p2(i) = derivative(list(distfun_gamcdf,shape, scale),x(i));
end
assert_checkalmostequal ( p1 , p2 , 1.e-7 , [] , "element");
