// Copyright (C) 2012 - Michael Baudin
// Copyright (C) 2011 - DIGITEO - Michael Baudin
//
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt

// <-- JVM NOT MANDATORY -->

// Set the seed so as to always get the same results.
grand("setsd",1);

// Use R = distfun_gamrnd ( a , b )
computed = distfun_gamrnd(1:6,(1:6)^-1);
assert_checkequal ( size ( computed ) , [1 6] );
computed = distfun_gamrnd(1:6,1);
assert_checkequal ( size ( computed ) , [1 6] );
computed = distfun_gamrnd(1,(1:6)^-1);
assert_checkequal ( size ( computed ) , [1 6] );

//
// Check expansion of a and b in R = distfun_gamrnd(a,b)
//
grand("setsd",1.0);
N = 10;
a = 1:6;
b = (1:6)^-1;
computed1 = [];
for i = 1:N
    computed1(i,1:6) = distfun_gamrnd(a,b);
end
grand("setsd",1.0);
computed2  = [];
for i = 1:N
    for k = 1 : 6
        computed2(i,k)=distfun_gamrnd(a(k),b(k));
    end
end
assert_checkequal(computed1,computed2);


// Check R = distfun_gamrnd ( a , b , v )
computed = distfun_gamrnd(2,1,[1 5]);
computed = distfun_gamrnd(2,1,[3 2]);

// Check mean and variance for R = distfun_gamrnd ( a , b )
N = 1000;
a = 2;
b = 3;
m = a .* b; // Expectation
v = m .* b; // Variance
computed = distfun_gamrnd(2,3,[1 N]);
c = mean(computed );
assert_checkalmostequal ( c , m,  0.1 );
c = st_deviation(computed );
e = sqrt(v);
assert_checkalmostequal ( c , e,  0.1 );

// Check R = distfun_gamrnd ( a , b , m , n )
computed = distfun_gamrnd([1 2 3;4 5 6],0.1,2,3);
assert_checkequal ( size ( computed ) , [2 3] );
computed = distfun_gamrnd(2,1,2,3);
assert_checkequal ( size ( computed ) , [2 3] );
computed = distfun_gamrnd(1,[1 2 3;4 5 6],2,3);
assert_checkequal ( size ( computed ) , [2 3] );

// Check mean and variance for R = distfun_gamrnd ( a , b )
N = 1000;
a = 2;
b = 3;
computed = distfun_gamrnd(a,b,1,N);
m = a .* b; // Expectation
v = m .* b; // Variance
c = mean(computed(1:N) );
assert_checkalmostequal ( c , m,  0.1 );
c = st_deviation(computed(1:N) );
e = sqrt(v);
assert_checkalmostequal ( c , e,  0.1 );

// Make a plot of the actual distribution of the numbers
if ( %f ) then
    a = 2;
    b = 3;
    data = distfun_gamrnd(a,b,1,1000);
    histplot(10,data)
    x = linspace(0,30,1000);
    y = distfun_gampdf(x,a,b);
    plot(x,y)
end
