// Copyright (C) 2011 - INRIA - Michael Baudin
// Copyright (C) 2011 - DIGITEO - Michael Baudin
//
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt


//
// <-- JVM NOT MANDATORY -->
// <-- ENGLISH IMPOSED -->

x = 2;
mu = 3;
sigma = 4;
computed = distfun_lognpdf ( x , mu , sigma );
expected = 4.222768901896055416D-02; // From Scilab itself
assert_checkalmostequal ( computed , expected , 10*%eps );
//
// Check matrix arguments
x = [2 2 2];
mu = [3 3 3];
sigma = [4 4 4];
computed = distfun_lognpdf ( x , mu , sigma );
expected = 4.222768901896055416D-02*ones(1,3); // From Scilab itself
assert_checkalmostequal ( computed , expected , 10*%eps );
//
// Check default sigma
x = [2 2 2];
mu = [3 3 3];
computed = distfun_lognpdf ( x , mu );
expected = 1.394170349688286445D-02*ones(1,3); // From Scilab itself
assert_checkalmostequal ( computed , expected , 10*%eps );
//
// Check default mu
x = [2 2 2];
computed = distfun_lognpdf ( x );
expected = 1.568740192789811194D-01*ones(1,3); // From Scilab itself
assert_checkalmostequal ( computed , expected , 10*%eps );
//
// Check argument expansion
x = [2 2 2];
mu = 3;
sigma = 4;
computed = distfun_lognpdf ( x , mu , sigma );
expected = 4.222768901896055416D-02*ones(1,3); // From Scilab itself
assert_checkalmostequal ( computed , expected , 10*%eps );
//
// Check vectorization
mu = 300;
sigma = 30;
t = linspace(mu-3*sigma,mu+3*sigma,10);
x = exp(t);
p = distfun_lognpdf ( x , mu , sigma );
p2 = [];
for i = 1 : 10
    p2(1,i) = distfun_lognpdf ( x(i) , mu , sigma );
end
assert_checkequal(p,p2);
//
// Check derivative
mu = 2;
sigma = 4;
t = mu;
x = exp(t);
c1 = distfun_logncdf ( x , mu , sigma );
h = x * 1.e-8;
c2 = distfun_logncdf ( x+h , mu , sigma );
p1 = (c2-c1)/h;
p2 = distfun_lognpdf ( x , mu , sigma );
assert_checkalmostequal(p1,p2,1.e-7);
//
// Check consistency CDF/PDF
n = 10;
mu = 2;
sigma = 4;
p = linspace(0.01,0.99,n)';
x = distfun_logninv(p,mu , sigma);
p1 = distfun_lognpdf ( x , mu , sigma );
p2 = [];
for i = 1 : n
    p2(i) = derivative(list(distfun_logncdf,mu , sigma),x(i));
end
assert_checkalmostequal ( p1 , p2 , 1.e-4 , [] , "element");
