// Copyright (C) 2009 - 2011 - DIGITEO - Michael Baudin
//
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt

// <-- JVM NOT MANDATORY -->
// <-- ENGLISH IMPOSED -->


//
// Test distfun_normcdf
//
computed = distfun_normcdf ( [-1 1] );
expected = [ 0.158655253931457   0.841344746068543 ];
assert_checkalmostequal ( computed , expected , %eps );
//
// Test argument expansion
computed = distfun_normcdf ( [1 2 3] , 1.0 , 2.0 );
expected = [ 0.500000000000000   0.691462461274013   0.841344746068543 ];
assert_checkalmostequal ( computed , expected , %eps );
//
// Test expanded arguments
computed = distfun_normcdf ( [1 2 3] , [1 1 1] , [2 2 2] );
expected = [ 0.500000000000000   0.691462461274013   0.841344746068543 ];
assert_checkalmostequal ( computed , expected , %eps );

/////////////////////////////////////////////////////////////////////
//
// Test accuracy of distfun_normcdf
//
// 
// References
// Assessing the quality of the Normal distribution function
// References
//   Yalta, A. T. 2008. The accuracy of statistical distributions in Microsoft®Excel 2007. Comput. Stat. Data Anal. 52, 10 (Jun. 2008), 4579-4586. DOI= http://dx.doi.org/10.1016/j.csda.2008.03.005 
//   Computation of Statistical Distributions (ELV), Leo Knüsel 
// Table 6
// Check inverse of normal law
//

// Values computed from Mathematica
table = [
  1.0 , 1.0 , 2.0 , 0.5 ,  %eps 
  2.0 , 1.0 , 2.0 , 0.6914624612740131 ,  %eps
  3.0 , 1.0 , 2.0 , 0.8413447460685429 ,  %eps
  4.0 , 1.0 , 2.0 , 0.9331927987311419 ,  %eps
  5.0 , 1.0 , 2.0 , 0.9772498680518208 ,  %eps
  -5.0 , 1.0 , 2.0 , 0.001349898031630095 , 10 * %eps
  -6.0 , 1.0 , 2.0 , 0.0002326290790355250 , 10 * %eps
  -10.0 , 1.0 , 2.0 , 1.898956246588772e-08 ,  10 * %eps
  -15.0 , 1.0 , 2.0 , 6.220960574271784e-16 , 10 * %eps
];
nt = size(table,"r");
for k = 1 : nt
  x = table(k,1);
  mu = table(k,2);
  sigma = table(k,3);
  expected = table(k,4);
  precision = table(k,5);
  computed = distfun_normcdf ( x , mu , sigma );
  assert_checkalmostequal ( computed , expected , precision );
end

//
// Check vectorization
mu = 300;
sigma = 30;
x = linspace(mu-3*sigma,mu+3*sigma,10);
p = distfun_normcdf ( x , mu , sigma );
p2 = [];
for i = 1 : 10
    p2(1,i) = distfun_normcdf ( x(i) , mu , sigma );
end
assert_checkequal(p,p2);

// See upper tail (compare with R)
p = distfun_normcdf ( 7, 4, 1 );
assert_checkalmostequal ( p , 0.99865010196837 , 1.e-15 );
p = distfun_normcdf ( 7, 4, 1 , %f );
assert_checkalmostequal ( p , 0.001349898031630095 , 1.e-15 );
p = distfun_normcdf ( 15, 4, 1 , %f );
assert_checkalmostequal ( p , 1.910659574498676e-28 , 1.e-15 );
