// Copyright (C) 2009 - 2011 - DIGITEO - Michael Baudin
//
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt

// <-- JVM NOT MANDATORY -->
// <-- ENGLISH IMPOSED -->


//
// Test distfun_norminv
//
computed = distfun_norminv ( [0.5 0.9 0.7] );
expected = [ 0.000000000000000   1.281551565544601   0.524400512708041 ];
assert_checkalmostequal ( computed , expected , 10 * %eps );
//
// Test argument expansion
computed = distfun_norminv ( [0.5 0.9 0.7] , 1.0 , 2.0 );
expected = [ 1.00000000000000   3.56310313108920   2.04880102541608 ];
assert_checkalmostequal ( computed , expected , 10 * %eps );
//
// Test with expanded arguments
computed = distfun_norminv ( [0.5 0.9 0.7] , [1 1 1] , [2 2 2] );
expected = [ 1.00000000000000   3.56310313108920   2.04880102541608 ];
assert_checkalmostequal ( computed , expected , 10 * %eps );
///////////////////////////////////////////////////////////////
//
// Test accuracy of distfun_norminv
//

// Values computed from Mathematica
table = [
  0.5 , 1.0 , 2.0 , 1.0 , 10 * %eps
  // Does not pass : fix the gateway, which does not manage the ieee status
  //0.0 , 1.0 , 2.0 , -%inf , 10 * %eps
  //1.0 , 1.0 , 2.0 , %inf , 10 * %eps
  0.6 , 1.0 , 2.0 ,  1.5066942062715996 , %eps
  0.8 , 1.0 , 2.0 , 2.6832424671458284 , %eps
  0.9 , 1.0 , 2.0 , 3.5631031310892009 , %eps
  0.2 , 1.0 , 2.0 , -0.6832424671458284 , 10 * %eps
  0.1 , 1.0 , 2.0 , -1.5631031310892009 , 10 * %eps
  1.e-2 , 1.0 , 2.0 , -3.6526957480816822 , %eps
  1.e-5 , 1.0 , 2.0 , -7.5297815878456493 , %eps
  1.e-10 , 1.0 , 2.0 , -11.722681804808112 , %eps
  1.e-20 , 1.0 , 2.0 , -17.524680179596815 , %eps
  1.e-50 , 1.0 , 2.0 , -28.866675069576978 , %eps
  1.e-100 , 1.0 , 2.0 , -41.546907121930649 , %eps
  1.e-200 , 1.0 , 2.0 , -59.411188359159286 , %eps
];
nt = size(table,"r");
for k = 1 : nt
  p = table(k,1);
  mu = table(k,2);
  sigma = table(k,3);
  expected = table(k,4);
  precision = table(k,5);
  computed = distfun_norminv ( p , mu , sigma );
  assert_checkalmostequal ( computed , expected , precision );
end

//
// Check vectorization
mu = 300;
sigma = 30;
p = linspace(0.1,0.9,10);
xx = distfun_norminv ( p , mu , sigma );
xx2 = [];
for i = 1 : 10
    xx2(1,i) = distfun_norminv ( p(i) , mu , sigma );
end
assert_checkequal(xx,xx2);
//
// See upper tail: compare with R
x=distfun_norminv(0.0001,1.,2.);
assert_checkalmostequal ( x , -6.4380329709113599534 , 1.e-15 );
x=distfun_norminv(0.0001,1.,2.,%f);
assert_checkalmostequal ( x ,  8.4380329709113599534 , 1.e-6 );
x=distfun_norminv(1.e-10,1.,2.,%f);
assert_checkalmostequal ( x , 13.722681804808111394 , 1.e-15 );

