// Copyright (C) 2009 - 2011 - DIGITEO - Michael Baudin
//
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt

// <-- JVM NOT MANDATORY -->


//
// Check with default mu, sigma
//
computed = distfun_normpdf ( [-1 1] );
expected = [ 0.241970724519143   0.241970724519143 ];
assert_checkalmostequal ( computed , expected , 10 * %eps );
//
// Check expansion of mu and expansion of sigma
computed = distfun_normpdf ( [1 2 3] , 1.0 , 2.0 );
expected = [ 0.199471140200716   0.176032663382150   0.120985362259572 ];
assert_checkalmostequal ( computed , expected , 10 * %eps );
//
// Check with expanded arguments
computed = distfun_normpdf ( [1 2 3] , [1 1 1], [2 2 2] );
expected = [ 0.199471140200716   0.176032663382150   0.120985362259572 ];
assert_checkalmostequal ( computed , expected , 10 * %eps );



///////////////////////////////////////////////////////////////
//
// Test accuracy of distfun_normpdf
//
// Numerical values computed from Mathematica

// Table of inputs
// [x shape scale P precision]
precision = 10*%eps;
table = [
  1.5 , 1.0 , 2.0 , 0.1933340584014246 , 10 * %eps 
  5.0 , 1.0 , 2.0 , 0.02699548325659403 , 10 * %eps
  10.0 , 1.0 , 2.0 , 7.991870553452737e-006 , 10 * %eps
  15.0 , 1.0 , 2.0 , 4.567360204182297e-012 , 10 * %eps
  20. , 1.0 , 2.0 , 5.038967697150005e-021 , 10 * %eps
  30. , 1.0 , 2.0 , 4.412377487297412e-047 , 100 * %eps
  50. , 1.0 , 2.0 , 9.062513967757624e-132 , 100 * %eps
  76. , 1.0 , 2.0 , 8.641168661420526e-307 , 100 * %eps
];

ntests = size(table,"r");
for i = 1 : ntests
  x = table(i,1);
  mu = table(i,2);
  sigma = table(i,3);
  expected = table(i,4);
  precision = table(i,5);
  computed = distfun_normpdf ( x , mu , sigma );
  assert_checkalmostequal ( computed , expected , precision );
end

//
// Check vectorization
mu = 300;
sigma = 30;
x = linspace(mu-3*sigma,mu+3*sigma,10);
p = distfun_normpdf ( x , mu , sigma );
p2 = [];
for i = 1 : 10
    p2(1,i) = distfun_normpdf ( x(i) , mu , sigma );
end
assert_checkequal(p,p2);
//
// Check consistency CDF/PDF
n = 10;
mu = 2;
sigma = 4;
p = linspace(0.01,0.99,n)';
x = distfun_norminv(p,mu , sigma);
p1 = distfun_normpdf ( x , mu , sigma );
p2 = [];
for i = 1 : n
    p2(i) = derivative(list(distfun_normcdf,mu , sigma),x(i));
end
assert_checkalmostequal ( p1 , p2 , 1.e-7 , [] , "element");
